/*******************************************************************************
 * Module to create files, resolves & opens files in write mode
 *
 * @author Zaneta Szymanska <<ahref='mailto:z.szymanska@samsung.com'>z.szymanska@samsung.com</a>>
 *
 * ******************************************************************************************************************
 *
 * Copyright (c) 2012 Samsung Electronics All Rights Reserved.
 *
 ******************************************************************************/
var filesystem = function($) {
    var gDocumentsDir;
    var textToWrite = '';

    /**
     * FileStreamSuccessCallback method, called when the file has been opened,
     * writes text to the file
     *
     * @param fileStream {Object} a handle to a File opened for read and/or
     *        write operations
     */
    var writeToStream = function(fileStream) {
        try {
            fileStream.write(textToWrite);
            fileStream.close();
        } catch (exc) {
            tlib.logger.err(exc.message);
        }
    };

    return {
        /**
         * Resolves a location to a file handle
         */
        init : function() {
            try {
                tizen.filesystem.resolve("documents", function(dir) {
                    gDocumentsDir = dir;
                }, function(e) {
                    tlib.logger.err("tizen.filesystem.resolve() error: "
                            + e.message);
                }, "rw");
            } catch (e) {
                tlib.logger.err("tizen.filesystem.resolve(\"documents\") exc: "
                        + e.message);
            }
        },

        /**
         * Creates file
         *
         * @param filename {String} Name of the file to create
         */
        createFile : function(filename) {
            try {
                gDocumentsDir.createFile(filename);
            } catch (exc) {
                if (exc.name === "IOError") {
                    tlib.logger.warn("File already exists");
                    return true;
                } else {
                    tlib.logger.err("Create file exception: " + exc.message);
                    return false;
                }
            }
        },

        /**
         * Resolves & opens file in write mode
         *
         * @param filename {String} Name of the file to open
         * @param text {String} Text to write in the file
         * @returns
         */
        writeToFile : function(filename, text) {
            var file;
            textToWrite = text;

            try {
                file = gDocumentsDir.resolve(filename);

                try {
                    file.openStream('w', writeToStream, shareContacts.onError);
                } catch (exc) {
                    tlib.logger.err('Could not write to file: ' + exc.message);
                }
            } catch (exc) {
                tlib.logger.err('Could not resolve file: ' + exc.message);
                return;
            }
        }
    };
}($);