/*******************************************************************************
 * Module to search messages, add messages to 'Draft' Folder in Message Storage
 *
 * @author Zaneta Szymanska <<ahref='mailto:z.szymanska@samsung.com'>z.szymanska@samsung.com</a>>
 *
 * ******************************************************************************************************************
 *
 * Copyright (c) 2012 Samsung Electronics All Rights Reserved.
 *
 ******************************************************************************/
var messages = function($) {

    return {
        /**
         * Searches messages from specified phone number
         *
         * @param phrase {String} phone number
         * @param callback {Object} contains callback functions
         * @returns
         */
        searchMessages : function(phrase, callback) {
            tizen.messaging.getMessageServices('messaging.sms', function(
                    services) {
                var fromFilter = new tizen.AttributeFilter("from", "EXACTLY",
                        phrase);

                tlib.logger.info("Searching for messages from " + phrase);

                try {
                    services[0].messageStorage.findMessages(fromFilter,
                            callback.success, callback.error);
                } catch (e) {
                    tlib.logger.err("Searching failed: " + e.name + ":"
                            + e.message);
                }
            }, shareContacts.onError);
        },

        /**
         * Adds a message to 'Draft messages' Folder in MessageStorage
         *
         * @param message {Object} message, which will be send in 'Draft
         *        messages' Folder
         * @param callback {Object} contains callback functions
         * @returns
         */
        addToDraft : function(message, callback) {
            tizen.messaging.getMessageServices('messaging.sms', function(
                    services) {
                tlib.logger.info("Saving in Drafts folder body: "
                        + message.body.plainBody);
                try {
                    services[0].messageStorage.addDraftMessage(message,
                            callback.success, callback.error);
                } catch (e) {
                    tlib.logger.err("Searching failed: " + e.name + ":"
                            + e.message);
                }
            }, shareContacts.onError);
        }
    };
}($);