/*******************************************************************************
 * Module to managing main view, creating list of all contacts
 *
 * @author Zaneta Szymanska <<ahref='mailto:z.szymanska@samsung.com'>z.szymanska@samsung.com</a>>
 *
 * ******************************************************************************************************************
 *
 * Copyright (c) 2012 Samsung Electronics All Rights Reserved.
 *
 ******************************************************************************/
var shareContacts = function($) {
    /**
     * Closes application if possible
     */
    var exit = function() {
        if (typeof tizen !== "undefined" && tizen.application) {
            if (confirm("Exit?")) {
                var app = tizen.application.getCurrentApplication();
                app.exit();
                tlib.logger.info("Application closed");
            }
        } else {
            alert("Not supported");
        }
    };

    var deleteElement = function(unchecked, that) {
        tlib.logger.info("Delete id: " + unchecked);
        // delete HTML element
        that.remove();
        $.each(contactsManager.getContactsToSend(), function(index, value) {
            // delete id from array
            if (value == unchecked) {
                contactsManager.getContactsToSend().splice(index, 1);
            }
        });

        if (contactsManager.getContactsToSend().length === 0) {
            $('#add-more-contacts').addClass('hidden');
        }
    };

    var addContactToList = function(contactId, that) {
        var exist = false, alertStr = "This contact exists on the list to send!";

        $.each(contactsManager.getContactsToSend(), function(index, value) {
            if (value === contactId) {
                tlib.logger.info(alertStr);
                tlib.view.showPopup(alertStr);
                exist = true;
            }
        });

        if (!exist) {
            // Add contact's id to array
            contactsManager.getContactsToSend().push(contactId);

            // Display contact on list to send
            var addContactStr = '<div id="' + contactId + '" class="row">'
                    + that.text() + '</div>';

            var contactElem = $(addContactStr).unbind().bind({
                click : function() {
                    var unchecked = $(this).attr("id");
                    deleteElement(unchecked, $(this));
                }
            });

            $('#contacts-table').append(contactElem);
            tlib.logger.info("Contacts to send array: "
                    + contactsManager.getContactsToSend());
        }
    };

    var hadleSwipeRight = function(that) {
        if (that.data("role") === 'list-divider') {
            return;
        }

        var contactId = that.data("id");

        $('#add-more-contacts').removeClass('hidden');

        if (contactsManager.getContactsToSend().length < 5) {
            addContactToList(contactId, that);
        } else {
            var alertStr = "You can send max. 5 contacts!";
            tlib.logger.warn(alertStr);
            tlib.view.showPopup(alertStr);
        }
    };

    var handleSwipeLeft = function(id) {
        var contact = addressBook.get(id), number = contact.phoneNumbers[0].number, phoneNumber;

        messageManager.getCheckedMessages().length = [];
        messageManager.getDisplayedMesssages().length = [];

        // To find all messages that contain contact's phone number, not
        // only these which contain full (with +48) phone number
        if (number.substring(0, 3) === "+48") {
            phoneNumber = number.substring(3, number.length);
        } else {
            if (number.substring(0, 2) === "48") {
                phoneNumber = number.substring(2, number.length);
            } else {
                phoneNumber = number;
            }
        }

        messages.searchMessages(phoneNumber, {
            success : messageManager.display,
            error : shareContacts.onError
        });

        // Set Page
        var msgLabel = "Messages from: " + phoneNumber;
        $('#label-msg-from').text(msgLabel.toString());

        $.mobile.changePage('#messages-page');

        $('#send-save-button').val("Send").button("refresh");
    };
    /**
     * Creates and refreshes list of contacts on main page
     *
     * @param contacts {Object}
     */
    var createListOfContacts = function(contacts) {
        var value, str = '', lastletter = '';

        for ( var i = 0; i < contacts.length; i++) {
            // Add the list divider
            if (contacts[i].name.firstName) {
                if (lastletter !== contacts[i].name.firstName[0]) {
                    lastletter = contacts[i].name.firstName[0];
                    str += '<li data-role="list-divider" data-item-type="contact">'
                            + lastletter + '</li>';
                }
            } else {
                if (lastletter !== '#') {
                    lastletter = '#';
                    str += '<li data-role="list-divider" data-item-type="contact"> # </li>';
                }
            }

            str += '<li class="ui-li-has-multiline" data-item-type="contact" data-id="'
                    + contacts[i].id
                    + '">'
                    + ((!contacts[i].name) ? ""
                            : (value = contacts[i].name.firstName) ? value : "")
                    + ' '
                    + ((!contacts[i].name) ? ""
                            : (value = contacts[i].name.lastName) ? value : "")
                    + '    '
                    + '<span class="ui-li-text-sub">&nbsp;&nbsp;&nbsp;'
                    + ((value = contacts[i].phoneNumbers[0]) ? value.number
                            : "") + '</span></li>';
        }

        // Remove contacts displayed previously
        $("#contacts-list>li[data-item-type=contact]").remove();

        var elem = $(str).unbind('swiperight').bind('swiperight', function(e) {
            var that = $(this);
            hadleSwipeRight(that);
        });

        elem.unbind('swipeleft').bind('swipeleft', function(e) {
            var id = $(this).data("id");
            handleSwipeLeft(id);
        });

        $("#contacts-list").append(elem).trigger("create").listview("refresh");
    };

    var messagesPageInit = function() {
        $("#messages-list").html('').trigger("create").listview("refresh");

        $("#messages-list").delegate("input", "change", function() {
            /**
             * On input change (checkbox) add/remove item to/from arraylist
             */
            var checkedMessages = messageManager.getCheckedMessages();

            if ($(this).prop("checked")) {
                checkedMessages.push($(this).val());
            } else {
                var unchecked = $(this).val();
                $.each(checkedMessages, function(index, value) {
                    if (value == unchecked) {
                        checkedMessages.splice(index, 1);
                    }
                });
            }

            tlib.logger.info("Checked messages' IDs: " + checkedMessages);
        });
    };

    var nfcCallbacks = {
        onattach : function() {
            tlib.view.showPopup("Device attached!");
            $('#detect-target-input').val('TARGET');
        },
        ondetach : function() {
            tlib.view.showPopup("Device detached!");
            $('#detect-target-input').val('NONE');
        },
        onreceive : function(message) {
            if (message.records[0].text.substring(0, 3) === "sms") {
                messageManager.handleMessageReceive(message);
            } else {
                contactsManager.handleContactReceive(message);
            }
        }
    };

    var fetchContacts = function() {
        // Fetch all contacts on list
        addressBook.fetchAllContacts({
            success : function(contacts) {
                createListOfContacts(contacts);
            },
            error : function() {
                tlib.logger.err("fetchAllContacts fail");
            }
        });
    };

    return {
        /**
         * Initializes Share Contacts application
         */
        initialize : function() {
            // TODO: set to 1 at the end
            // 1 - only warnings and errors, 2 - logs too
            tlib.logger.changeLogLevel(1);

            filesystem.init();

            nfc.init(nfcCallbacks);

            fetchContacts();

            $('.exit').unbind().bind({
                click : function() {
                    exit();
                }
            });

            $('.home').unbind().bind({
                click : function(event) {
                    event.preventDefault();
                    $.mobile.changePage('#main-page');
                }
            });

            $('.back').unbind().bind({
                click : function(event) {
                    event.preventDefault();
                    $.mobile.changePage('#messages-page');
                }
            });

            $('#send-contacts').unbind().bind({
                click : function(event) {
                    event.preventDefault();
                    contactsManager.sendContacts();
                }
            });

            $("#send-save-button").unbind().bind({
                click : function(event) {
                    /**
                     * Checks if messages should be send or save, invokes proper
                     * method
                     */
                    event.preventDefault();

                    if ($("#send-save-button").val() === "Send") {
                        messageManager.sendMessages();
                    } else {
                        messageManager.saveInDraftsFolder();
                    }
                }
            });

            $('#main-page').live(
                    'pageinit',
                    function() {
                        $("#contacts-list").html('').trigger("create")
                                .listview("refresh");
                    });

            $('#messages-page').live('pageinit', function() {
                messagesPageInit();
            });

            tlib.visibility.onApplicationVisible(function() {
                fetchContacts();
            });
        },

        listOfContacts : function(contacts) {
            createListOfContacts(contacts);
        },

        /**
         * ErrorCallback
         *
         * @param err
         */
        onError : function(err) {
            tlib.logger.err("Error: " + err.message);
        }
    };
}($);